@@ -387,8 +387,8 @@ class _RealTimeJsonEventPicker:
                         "type": "severity_hit",
                         "severity": severity_level,
                         "ascending": ascending,
-                        "frame_id": frame_id-6,
-                        "video_timestamp_secs": int(frame_id-6)/30
+                        "frame_id": int(frame_id)-6,
+                        "video_timestamp_secs": (int(frame_id)-6)/30
                     }
                     # Advance to next required severity
                     self._sequence.popleft()
