@@ -451,6 +451,9 @@ class ConfigManager:
             'smoker_detection': None,
             'road_traffic_density': None,
             'road_view_segmentation': None,
+            'face_recognition': None,
+            'drowsy_driver_detection': None,
+            'waterbody_segmentation': None,
 
             #Put all image based usecases here::
             'blood_cancer_detection_img': None,
@@ -823,6 +826,30 @@ class ConfigManager:
         except ImportError:
             return None
     
+    def face_recognition_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.face_recognition import FaceRecognitionConfig
+            return FaceRecognitionConfig
+        except ImportError:
+            return None
+    
+    def drowsy_driver_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.drowsy_driver_detection import DrowsyDriverConfig
+            return DrowsyDriverConfig
+        except ImportError:
+            return None
+    
+    def waterbody_segmentation_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.waterbody_segmentation import WaterBodyConfig
+            return WaterBodyConfig
+        except ImportError:
+            return None
+    
     #put all image based usecases here::
     def blood_cancer_detection_config_class(self):
         """Register a configuration class for a use case."""
@@ -1711,6 +1738,53 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+        
+        elif usecase == "face_recognition":
+            # Import here to avoid circular import
+            from ..usecases.face_recognition import FaceRecognitionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = FaceRecognitionConfig(
+                category=category or "security",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+        elif usecase == "drowsy_driver_detection":
+            # Import here to avoid circular import
+            from ..usecases.drowsy_driver_detection import DrowsyDriverConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = DrowsyDriverConfig(
+                category=category or "automobile",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+        
+        elif usecase == "waterbody_segmentation":
+            # Import here to avoid circular import
+            from ..usecases.waterbody_segmentation import WaterBodyConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = WaterBodyConfig(
+                category=category or "agriculture",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
 
         
         #Add IMAGE based usecases here::
@@ -2141,6 +2215,21 @@ class ConfigManager:
             from ..usecases.road_view_segmentation import RoadViewSegmentationConfig
             default_config = RoadViewSegmentationConfig()
             return default_config.to_dict()
+        elif usecase == "face_recognition":
+            # Import here to avoid circular import
+            from ..usecases.face_recognition import FaceRecognitionConfig
+            default_config = FaceRecognitionConfig()
+            return default_config.to_dict()
+        elif usecase == "drowsy_driver_detection":
+            # Import here to avoid circular import
+            from ..usecases.drowsy_driver_detection import DrowsyDriverConfig
+            default_config = DrowsyDriverConfig()
+            return default_config.to_dict()
+        elif usecase == "waterbody_segmentation":
+            # Import here to avoid circular import
+            from ..usecases.waterbody_segmentation import WaterBodyConfig
+            default_config = WaterBodyConfig()
+            return default_config.to_dict()
 
         #Add all image based usecases here
         elif usecase == "blood_cancer_detection_img":
