@@ -86,6 +86,9 @@ from .usecases import (
     SmokerDetectionUseCase,
     RoadTrafficUseCase,
     RoadViewSegmentationUseCase,
+    FaceRecognitionUseCase,
+    DrowsyDriverUseCase,
+    WaterBodyUseCase,
 
     #Put all IMAGE based usecases here
     BloodCancerDetectionUseCase,
@@ -213,6 +216,9 @@ class PostProcessor:
         registry.register_use_case("general", "smoker_detection", SmokerDetectionUseCase)
         registry.register_use_case("automobile", "road_traffic_density", RoadTrafficUseCase)
         registry.register_use_case("automobile", "road_view_segmentation", RoadViewSegmentationUseCase)
+        registry.register_use_case("security", "face_recognition", FaceRecognitionUseCase)
+        registry.register_use_case("automobile", "drowsy_driver_detection", DrowsyDriverUseCase)
+        registry.register_use_case("agriculture", "waterbody_segmentation", WaterBodyUseCase)
 
         #Put all IMAGE based usecases here
         registry.register_use_case("healthcare", "bloodcancer_img_detection", BloodCancerDetectionUseCase)
@@ -377,6 +383,12 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, RoadViewSegmentationUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, FaceRecognitionUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, DrowsyDriverUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, WaterBodyUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
 
             
             #Put all IMAGE based usecases here
