@@ -63,7 +63,10 @@ from .parking import ParkingConfig, ParkingUseCase
 from .leaf import LeafConfig, LeafUseCase
 from .smoker_detection import SmokerDetectionConfig, SmokerDetectionUseCase
 from .road_traffic_density import RoadTrafficConfig, RoadTrafficUseCase
-from .road_lane_segmentation import RoadViewSegmentationConfig, RoadViewSegmentationUseCase
+from .road_view_segmentation import RoadViewSegmentationConfig, RoadViewSegmentationUseCase
+from .face_recognition import FaceRecognitionConfig, FaceRecognitionUseCase
+from .drowsy_driver_detection import DrowsyDriverUseCase, DrowsyDriverUseCase
+from .waterbody_segmentation import WaterBodyConfig, WaterBodyUseCase
 
 #Put all IMAGE based usecases here
 from .blood_cancer_detection_img import BloodCancerDetectionConfig, BloodCancerDetectionUseCase
@@ -125,6 +128,9 @@ __all__ = [
     'SmokerDetectionUseCase',
     'RoadTrafficUseCase',
     'RoadViewSegmentationUseCase',
+    'FaceRecognitionUseCase',
+    'DrowsyDriverUseCase',
+    'WaterBodyUseCase',
 
     #Put all IMAGE based usecases here
     'BloodCancerDetectionUseCase',
@@ -186,6 +192,9 @@ __all__ = [
     'SmokerDetectionConfig',
     'RoadTrafficConfig',
     'RoadViewSegmentationConfig',
+    'FaceRecognitionConfig',
+    'DrowsyDriverUseCase',
+    'WaterBodyConfig',
 
 
 
