@@ -3,7 +3,7 @@ from dataclasses import asdict
 import time
 from datetime import datetime, timezone
 
-from ..core.base import BaseProcessor, ProcessingContext, ProcessingResult, ConfigProtocol
+from ..core.base import BaseProcessor, ProcessingContext, ProcessingResult, ConfigProtocol, ResultFormat
 from ..utils import (
     filter_by_confidence,
     filter_by_categories,
@@ -19,10 +19,9 @@ from ..utils import (
 from dataclasses import dataclass, field
 from ..core.config import BaseConfig, AlertConfig, ZoneConfig
 
-
 @dataclass
 class VehicleMonitoringConfig(BaseConfig):
-    """Configuration for vehicle monitoring use case."""
+    """Configuration for vehicle detection use case in vehicle monitoring."""
     enable_smoothing: bool = True
     smoothing_algorithm: str = "observability"
     smoothing_window_size: int = 20
@@ -30,7 +29,11 @@ class VehicleMonitoringConfig(BaseConfig):
     smoothing_confidence_range_factor: float = 0.5
     confidence_threshold: float = 0.6
     usecase_categories: List[str] = field(
-        default_factory=lambda: ['bicycle', 'car', 'motorbike', 'auto rickshaw', 'bus', 'garbagevan', 'truck', 'minibus', 'army vehicle', 'pickup', 'policecar', 'rickshaw', 'scooter', 'suv', 'taxi', 'three wheelers -CNG-', 'human hauler', 'van', 'wheelbarrow']
+        default_factory=lambda: [
+            "bicycle", "car", "motorbike", "auto rickshaw", "bus", "garbagevan",
+            "truck", "minibus", "army vehicle", "pickup", "policecar", "rickshaw",
+            "scooter", "suv", "taxi", "three wheelers -CNG-", "human hauler", "van", "wheelbarrow"
+        ]
     )
     target_categories: List[str] = field(
         default_factory=lambda: ['car', 'bicycle', 'bus', 'garbagevan', 'truck', 'motorbike', 'van']
@@ -38,54 +41,40 @@ class VehicleMonitoringConfig(BaseConfig):
     alert_config: Optional[AlertConfig] = None
     index_to_category: Optional[Dict[int, str]] = field(
         default_factory=lambda: {
-            0: "ambulance",
-            1: "army vehicle",
-            2: "car",
-            3: "bicycle",
-            4: "bus",
-            5: "auto rickshaw",
-            6: "garbagevan",
-            7: "truck",
-            8: "minibus",
-            9: "minivan",
-            10: "motorbike",
-            11: "pickup",
-            12: "policecar",
-            13: "rickshaw",
-            14: "scooter",
-            15: "suv",
-            16: "taxi",
-            17: "three wheelers -CNG-",
-            18: "human hauler",
-            19: "van",
-            20: "wheelbarrow"
-        }
+                0: "ambulance",
+                1: "army vehicle",
+                2: "car",
+                3: "bicycle",
+                4: "bus",
+                5: "auto rickshaw",
+                6: "garbagevan",
+                7: "truck",
+                8: "minibus",
+                9: "minivan",
+                10: "motorbike",
+                11: "pickup",
+                12: "policecar",
+                13: "rickshaw",
+                14: "scooter",
+                15: "suv",
+                16: "taxi",
+                17: "three wheelers -CNG-",
+                18: "human hauler",
+                19: "van",
+                20: "wheelbarrow"
+            }
     )
 
-
 class VehicleMonitoringUseCase(BaseProcessor):
     CATEGORY_DISPLAY = {
-        "bicycle": "Bicycle",
-        "car": "Car",
-        "motorbike": "Motorbike",
-        "auto rickshaw": "Auto Rickshaw",
-        "bus": "Bus",
-        "garbagevan": "Garbage Van",
-        "truck": "Truck",
-        "minibus": "Minibus",
-        "army vehicle": "Army Vehicle",
-        "pickup": "Pickup",
-        "policecar": "Police Car",
-        "rickshaw": "Rickshaw",
-        "scooter": "Scooter",
-        "suv": "SUV",
-        "taxi": "Taxi",
-        "three wheelers -CNG-": "Three Wheelers (CNG)",
-        "human hauler": "Human Hauler",
-        "van": "Van",
-        "wheelbarrow": "Wheelbarrow"
+        "bicycle": "Bicycle", "car": "Car", "motorbike": "Motorbike", "auto rickshaw": "Auto Rickshaw",
+        "bus": "Bus", "garbagevan": "Garbage Van", "truck": "Truck", "minibus": "Minibus",
+        "army vehicle": "Army Vehicle", "pickup": "Pickup", "policecar": "Police Car",
+        "rickshaw": "Rickshaw", "scooter": "Scooter", "suv": "SUV", "taxi": "Taxi",
+        "three wheelers -CNG-": "Three Wheelers (CNG)", "human hauler": "Human Hauler",
+        "van": "Van", "wheelbarrow": "Wheelbarrow"
     }
-    
+
     def __init__(self):
         super().__init__("vehicle_monitoring")
         self.category = "traffic"
@@ -121,7 +110,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
             self.logger.debug(f"Applied confidence filtering with threshold {config.confidence_threshold}")
         else:
             processed_data = data
-            self.logger.debug("No confidence filtering applied")
+            self.logger.debug("Did not apply confidence filtering since no threshold provided")
 
         if config.index_to_category:
             processed_data = apply_category_mapping(processed_data, config.index_to_category)
@@ -170,6 +159,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
         counting_summary = self._count_categories(processed_data, config)
         total_counts = self.get_total_counts()
         counting_summary['total_counts'] = total_counts
+
         alerts = self._check_alerts(counting_summary, frame_number, config)
         predictions = self._extract_predictions(processed_data)
 
@@ -252,9 +242,9 @@ class VehicleMonitoringUseCase(BaseProcessor):
         total_detections = counting_summary.get("total_count", 0)
         current_timestamp = self._get_current_timestamp_str(stream_info)
         camera_info = self.get_camera_info_from_stream(stream_info)
-        
+
         self._ascending_alert_list = self._ascending_alert_list[-900:] if len(self._ascending_alert_list) > 900 else self._ascending_alert_list
-        
+
         if total_detections > 0:
             level = "low"
             intensity = 5.0
@@ -266,7 +256,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
                     self.current_incident_end_timestamp = current_timestamp
             elif self.current_incident_end_timestamp != 'Incident still active' and self.current_incident_end_timestamp != 'N/A':
                 self.current_incident_end_timestamp = 'N/A'
-                
+
             if config.alert_config and config.alert_config.count_thresholds:
                 threshold = config.alert_config.count_thresholds.get("all", 15)
                 intensity = min(10.0, (total_detections / threshold) * 10)
@@ -352,7 +342,17 @@ class VehicleMonitoringUseCase(BaseProcessor):
         for detection in counting_summary.get("detections", []):
             bbox = detection.get("bounding_box", {})
             category = detection.get("category", "vehicle")
-            detection_obj = self.create_detection_object(category, bbox)
+            if detection.get("masks"):
+                segmentation = detection.get("masks", [])
+                detection_obj = self.create_detection_object(category, bbox, segmentation=segmentation)
+            elif detection.get("segmentation"):
+                segmentation = detection.get("segmentation")
+                detection_obj = self.create_detection_object(category, bbox, segmentation=segmentation)
+            elif detection.get("mask"):
+                segmentation = detection.get("mask")
+                detection_obj = self.create_detection_object(category, bbox, segmentation=segmentation)
+            else:
+                detection_obj = self.create_detection_object(category, bbox)
             detections.append(detection_obj)
 
         alert_settings = []
@@ -382,7 +382,6 @@ class VehicleMonitoringUseCase(BaseProcessor):
         human_text = "\n".join(human_text_lines)
 
         reset_settings = [{"interval_type": "daily", "reset_time": {"value": 9, "time_unit": "hour"}}]
-
         tracking_stat = self.create_tracking_stats(
             total_counts=total_counts,
             current_counts=current_counts,
@@ -402,19 +401,18 @@ class VehicleMonitoringUseCase(BaseProcessor):
                                     stream_info: Optional[Dict[str, Any]] = None, is_empty=False) -> List[Dict]:
         if is_empty:
             return []
-        return []
 
-    def _generate_summary(self, summary: dict, incidents: List, tracking_stats: List, business_analytics: List, alerts: List) -> List[Dict]:
+    def _generate_summary(self, summary: dict, incidents: List, tracking_stats: List, business_analytics: List, alerts: List) -> List[str]:
         lines = {}
         lines["Application Name"] = self.CASE_TYPE
         lines["Application Version"] = self.CASE_VERSION
-        if incidents:
-            lines["Incidents"] = f"\n\t{incidents[0].get('human_text', 'No incidents detected')}\n"
-        if tracking_stats:
-            lines["Tracking Statistics"] = f"\t{tracking_stats[0].get('human_text', 'No tracking statistics detected')}\n"
-        if business_analytics:
-            lines["Business Analytics"] = f"\t{business_analytics[0].get('human_text', 'No business analytics detected')}\n"
-        if not incidents and not tracking_stats and not business_analytics:
+        if len(incidents) > 0:
+            lines["Incidents:"] = f"\n\t{incidents[0].get('human_text', 'No incidents detected')}\n"
+        if len(tracking_stats) > 0:
+            lines["Tracking Statistics:"] = f"\t{tracking_stats[0].get('human_text', 'No tracking statistics detected')}\n"
+        if len(business_analytics) > 0:
+            lines["Business Analytics:"] = f"\t{business_analytics[0].get('human_text', 'No business analytics detected')}\n"
+        if len(incidents) == 0 and len(tracking_stats) == 0 and len(business_analytics) == 0:
             lines["Summary"] = "No Summary Data"
         return [lines]
 
@@ -465,20 +463,26 @@ class VehicleMonitoringUseCase(BaseProcessor):
         seconds = round(float(timestamp % 60), 2)
         return f"{hours:02d}:{minutes:02d}:{seconds:.1f}"
 
-    def _get_current_timestamp_str(self, stream_info: Optional[Dict[str, Any]], precision=False) -> str:
-        if not stream_info or isinstance(stream_info, str):
-            return "00:00:00.00" if not precision else "00:00:00.000000"
+    def _get_current_timestamp_str(self, stream_info: Optional[Dict[str, Any]], precision=False, frame_id: Optional[str]=None) -> str:
+        if not stream_info:
+            return "00:00:00.00"
         if precision:
-            if stream_info.get("feed_type", "live") == "disk":
-                start_time = stream_info.get("start_frame", 30) / stream_info.get("original_fps", 30)
+            if stream_info.get("input_settings", {}).get("start_frame", "na") != "na":
+                if frame_id:
+                    start_time = int(frame_id)/stream_info.get("input_settings", {}).get("original_fps", 30)
+                else:
+                    start_time = stream_info.get("input_settings", {}).get("start_frame", 30)/stream_info.get("input_settings", {}).get("original_fps", 30)
                 return self._format_timestamp_for_video(start_time)
             else:
                 return datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S.%f UTC")
-        if stream_info.get("feed_type", "live") == "disk":
-            start_time = stream_info.get("start_frame", 30) / stream_info.get("original_fps", 30)
+        if stream_info.get("input_settings", {}).get("start_frame", "na") != "na":
+            if frame_id:
+                start_time = int(frame_id)/stream_info.get("input_settings", {}).get("original_fps", 30)
+            else:
+                start_time = stream_info.get("input_settings", {}).get("start_frame", 30)/stream_info.get("input_settings", {}).get("original_fps", 30)
             return self._format_timestamp_for_video(start_time)
         else:
-            stream_time_str = stream_info.get("stream_info", {}).get("stream_time", "") if isinstance(stream_info.get("stream_info"), dict) else ""
+            stream_time_str = stream_info.get("input_settings", {}).get("stream_info", {}).get("stream_time", "")
             if stream_time_str:
                 try:
                     timestamp_str = stream_time_str.replace(" UTC", "")
@@ -491,18 +495,18 @@ class VehicleMonitoringUseCase(BaseProcessor):
                 return self._format_timestamp_for_stream(time.time())
 
     def _get_start_timestamp_str(self, stream_info: Optional[Dict[str, Any]], precision=False) -> str:
-        if not stream_info or isinstance(stream_info, str):
-            return "00:00:00" if not precision else "00:00:00.000000"
+        if not stream_info:
+            return "00:00:00"
         if precision:
-            if stream_info.get("feed_type", "live") == "disk":
+            if stream_info.get("input_settings", {}).get("start_frame", "na") != "na":
                 return "00:00:00"
             else:
                 return datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S.%f UTC")
-        if stream_info.get("feed_type", "live") == "disk":
+        if stream_info.get("input_settings", {}).get("start_frame", "na") != "na":
             return "00:00:00"
         else:
             if self._tracking_start_time is None:
-                stream_time_str = stream_info.get("stream_info", {}).get("stream_time", "") if isinstance(stream_info.get("stream_info"), dict) else ""
+                stream_time_str = stream_info.get("input_settings", {}).get("stream_info", {}).get("stream_time", "")
                 if stream_time_str:
                     try:
                         timestamp_str = stream_time_str.replace(" UTC", "")
@@ -560,7 +564,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
                 values = [v for v in bbox.values() if isinstance(v, (int, float))]
                 return values[:4] if len(values) >= 4 else []
             return []
-        
+
         l1 = _bbox_to_list(box1)
         l2 = _bbox_to_list(box2)
         if len(l1) < 4 or len(l2) < 4:
